@@ -3,7 +3,6 @@
 /* eslint-env mocha */
 
 const assert = require('assert')
-const fs = require('fs')
 const fse = require('..')
 
 const methods = [
@@ -24,11 +23,8 @@ describe('promise support', () => {
     })
   })
 
-  if (Object.getOwnPropertyDescriptor(fs, 'promises')) {
-    it('provides fse.promises API', () => {
-      const desc = Object.getOwnPropertyDescriptor(fse, 'promises')
-      assert.ok(desc)
-      assert.strictEqual(typeof desc.get, 'function')
-    })
-  }
+  it('provides fse.promises API', () => {
+    assert.ok(fse.promises)
+    assert.strictEqual(typeof fse.promises.writeFile, 'function')
+  })
 })
