@@ -149,14 +149,14 @@ describe('+ copy() - prevent copying into itself', () => {
     })
 
     describe('>> when dest is a symlink', () => {
-      it('should error when dest points exactly to src', done => {
+      it('should error when dest points exactly to src and dereference is true', done => {
         const destLink = path.join(TEST_DIR, 'dest-symlink')
         fs.symlinkSync(src, destLink, 'dir')
 
         const srclenBefore = klawSync(src).length
         assert(srclenBefore > 2)
 
-        fs.copy(src, destLink, err => {
+        fs.copy(src, destLink, { dereference: true }, err => {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
 
           const srclenAfter = klawSync(src).length
@@ -210,7 +210,7 @@ describe('+ copy() - prevent copying into itself', () => {
         })
       })
 
-      it('should copy the directory successfully when src is a subdir of resolved dest path', done => {
+      it('should copy the directory successfully when src is a subdir of resolved dest path and dereference is true', done => {
         const srcInDest = path.join(TEST_DIR, 'dest', 'some', 'nested', 'src')
         const destLink = path.join(TEST_DIR, 'dest-symlink')
         fs.copySync(src, srcInDest) // put some stuff in srcInDest
@@ -222,7 +222,7 @@ describe('+ copy() - prevent copying into itself', () => {
         const destlenBefore = klawSync(dest).length
 
         assert(srclen > 2)
-        fs.copy(srcInDest, destLink, err => {
+        fs.copy(srcInDest, destLink, { dereference: true }, err => {
           assert.ifError(err)
 
           const destlenAfter = klawSync(dest).length
@@ -321,7 +321,7 @@ describe('+ copy() - prevent copying into itself', () => {
     })
 
     describe('>> when dest is a symlink', () => {
-      it('should error when resolved dest path is exactly the same as resolved src path', done => {
+      it('should error when resolved dest path is exactly the same as resolved src path and dereference is true', done => {
         const srcLink = path.join(TEST_DIR, 'src-symlink')
         fs.symlinkSync(src, srcLink, 'dir')
         const destLink = path.join(TEST_DIR, 'dest-symlink')
@@ -332,7 +332,7 @@ describe('+ copy() - prevent copying into itself', () => {
         assert(srclenBefore > 2)
         assert(destlenBefore > 2)
 
-        fs.copy(srcLink, destLink, err => {
+        fs.copy(srcLink, destLink, { dereference: true }, err => {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
 
           const srclenAfter = klawSync(srcLink).length
@@ -364,24 +364,6 @@ describe('+ copy() - prevent copying into itself', () => {
           done()
         })
       })
-
-      it('should error when resolved src path is a subdir of resolved dest path', done => {
-        const srcInDest = path.join(TEST_DIR, 'dest', 'some', 'nested', 'src')
-        const srcLink = path.join(TEST_DIR, 'src-symlink')
-        const destLink = path.join(TEST_DIR, 'dest-symlink')
-        const dest = path.join(TEST_DIR, 'dest')
-
-        fs.ensureDirSync(srcInDest)
-        fs.ensureSymlinkSync(srcInDest, srcLink, 'dir')
-        fs.ensureSymlinkSync(dest, destLink, 'dir')
-
-        fs.copy(srcLink, destLink, err => {
-          assert.strictEqual(err.message, `Cannot overwrite '${dest}' with '${srcInDest}'.`)
-          const destln = fs.readlinkSync(destLink)
-          assert.strictEqual(destln, dest)
-          done()
-        })
-      })
     })
   })
 })
