@@ -37,7 +37,7 @@ describe('ncp / error / dest-permission', () => {
     fse.outputFileSync(someFile, 'hello')
 
     fse.mkdirsSync(dest)
-    fs.chmodSync(dest, parseInt('444', 8))
+    fs.chmodSync(dest, 0o444)
 
     const subdest = path.join(dest, 'another-dir')
 
