@@ -44,10 +44,8 @@ describe('ncp', () => {
             for (const fileName in files) {
               const curFile = files[fileName]
               if (curFile instanceof Object) {
-                return filter(curFile)
-              }
-
-              if (fileName.substr(fileName.length - 1) === 'a') {
+                filter(curFile)
+              } else if (fileName.substr(fileName.length - 1) === 'a') {
                 delete files[fileName]
               }
             }
