@@ -46,7 +46,7 @@ describe('fs-extra', () => {
       it('should give clear error if node in directory tree is a file', done => {
         const existingFile = path.join(TEST_DIR, Math.random() + 'ts-e', Math.random() + '.txt')
         fse.mkdirsSync(path.dirname(existingFile))
-        fs.writeFileSync(existingFile)
+        fs.writeFileSync(existingFile, '')
 
         const file = path.join(existingFile, Math.random() + '.txt')
         fse.createFile(file, err => {
@@ -79,7 +79,7 @@ describe('fs-extra', () => {
       it('should give clear error if node in directory tree is a file', () => {
         const existingFile = path.join(TEST_DIR, Math.random() + 'ts-e', Math.random() + '.txt')
         fse.mkdirsSync(path.dirname(existingFile))
-        fs.writeFileSync(existingFile)
+        fs.writeFileSync(existingFile, '')
 
         const file = path.join(existingFile, Math.random() + '.txt')
         try {
