@@ -31,4 +31,21 @@ describe('jsonfile-integration', () => {
       assert.strictEqual(data, JSON.stringify(obj1) + '\n')
     })
   })
+
+  describe('+ writeJsonSync / EOL', () => {
+    it('should read a file and parse the json', () => {
+      const obj1 = {
+        firstName: 'JP',
+        lastName: 'Richardson'
+      }
+
+      const file = path.join(TEST_DIR, 'file.json')
+      fse.writeJsonSync(file, obj1, { spaces: 2, EOL: '\r\n' })
+      const data = fs.readFileSync(file, 'utf8')
+      assert.strictEqual(
+        data,
+        JSON.stringify(obj1, null, 2).replace(/\n/g, '\r\n') + '\r\n'
+      )
+    })
+  })
 })
