@@ -5,7 +5,6 @@ const os = require('os')
 const fse = require(process.cwd())
 const path = require('path')
 const assert = require('assert')
-const mkdirs = require('../mkdirs')
 
 /* global beforeEach, describe, it */
 
@@ -22,7 +21,7 @@ describe('mkdirs / opts-undef', () => {
     const newDir = path.join(TEST_DIR, 'doest', 'not', 'exist')
     assert(!fs.existsSync(newDir))
 
-    mkdirs(newDir, undefined, err => {
+    fse.mkdirs(newDir, undefined, err => {
       assert.ifError(err)
       assert(fs.existsSync(newDir))
       done()
