@@ -113,7 +113,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
 
   describe('> when src is a directory', () => {
     describe('>> when src is regular and dest is a symlink that points to src', () => {
-      it('should error', () => {
+      it('should error if dereferene is true', () => {
         src = path.join(TEST_DIR, 'src')
         fs.mkdirsSync(src)
         const subdir = path.join(TEST_DIR, 'src', 'subdir')
@@ -126,7 +126,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
         const oldlen = klawSync(src).length
 
         try {
-          fs.moveSync(src, destLink)
+          fs.moveSync(src, destLink, { dereference: true })
         } catch (err) {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
         }
@@ -166,7 +166,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
     })
 
     describe('>> when src and dest are symlinks that point to the exact same path', () => {
-      it('should error src and dest are the same', () => {
+      it('should error if src and dest are the same and dereference is true', () => {
         src = path.join(TEST_DIR, 'src')
         fs.mkdirsSync(src)
         const srcLink = path.join(TEST_DIR, 'src_symlink')
@@ -178,7 +178,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
         const destlenBefore = klawSync(destLink).length
 
         try {
-          fs.moveSync(srcLink, destLink)
+          fs.moveSync(srcLink, destLink, { dereference: true })
         } catch (err) {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
         }
@@ -203,7 +203,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
 
   describe('> when src is a file', () => {
     describe('>> when src is regular and dest is a symlink that points to src', () => {
-      it('should error', () => {
+      it('should error if dereference is true', () => {
         src = path.join(TEST_DIR, 'src', 'somefile.txt')
         fs.ensureFileSync(src)
         fs.writeFileSync(src, 'some data')
@@ -212,7 +212,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
         fs.symlinkSync(src, destLink, 'file')
 
         try {
-          fs.moveSync(src, destLink)
+          fs.moveSync(src, destLink, { dereference: true })
         } catch (err) {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
         }
@@ -243,7 +243,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
     })
 
     describe('>> when src and dest are symlinks that point to the exact same path', () => {
-      it('should error src and dest are the same', () => {
+      it('should error if src and dest are the same and dereference is true', () => {
         src = path.join(TEST_DIR, 'src', 'srcfile.txt')
         fs.outputFileSync(src, 'src data')
 
@@ -254,7 +254,7 @@ describe('+ moveSync() - prevent moving identical files and dirs', () => {
         fs.symlinkSync(src, destLink, 'file')
 
         try {
-          fs.moveSync(srcLink, destLink)
+          fs.moveSync(srcLink, destLink, { dereference: true })
         } catch (err) {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
         }
