@@ -52,30 +52,27 @@ describe('+ move() - prevent moving into itself', () => {
         done()
       })
     })
-  })
-
-  describe('> when source is a file', () => {
-    it(`should move the file successfully even when dest parent is 'src/dest'`, done => {
+    it("should move the file successfully even when dest parent is 'src/dest'", done => {
       const destFile = path.join(TEST_DIR, 'src', 'dest', 'destfile.txt')
       return testSuccessFile(src, destFile, done)
     })
 
-    it(`should move the file successfully when dest parent is 'src/src_dest'`, done => {
+    it("should move the file successfully when dest parent is 'src/src_dest'", done => {
       const destFile = path.join(TEST_DIR, 'src', 'src_dest', 'destfile.txt')
       return testSuccessFile(src, destFile, done)
     })
 
-    it(`should move the file successfully when dest parent is 'src/dest_src'`, done => {
+    it("should move the file successfully when dest parent is 'src/dest_src'", done => {
       const destFile = path.join(TEST_DIR, 'src', 'dest_src', 'destfile.txt')
       return testSuccessFile(src, destFile, done)
     })
 
-    it(`should move the file successfully when dest parent is 'src/dest/src'`, done => {
+    it("should move the file successfully when dest parent is 'src/dest/src'", done => {
       const destFile = path.join(TEST_DIR, 'src', 'dest', 'src', 'destfile.txt')
       return testSuccessFile(src, destFile, done)
     })
 
-    it(`should move the file successfully when dest parent is 'srcsrc/dest'`, done => {
+    it("should move the file successfully when dest parent is 'srcsrc/dest'", done => {
       const destFile = path.join(TEST_DIR, 'srcsrc', 'dest', 'destfile.txt')
       return testSuccessFile(src, destFile, done)
     })
@@ -83,59 +80,59 @@ describe('+ move() - prevent moving into itself', () => {
 
   describe('> when source is a directory', () => {
     describe('>> when dest is a directory', () => {
-      it(`of not itself`, done => {
+      it('of not itself', done => {
         const dest = path.join(TEST_DIR, src.replace(/^\w:/, ''))
         return testSuccessDir(src, dest, done)
       })
-      it(`of itself`, done => {
+      it('of itself', done => {
         const dest = path.join(src, 'dest')
         return testError(src, dest, done)
       })
-      it(`should move the directory successfully when dest is 'src_dest'`, done => {
+      it("should move the directory successfully when dest is 'src_dest'", done => {
         const dest = path.join(TEST_DIR, 'src_dest')
         return testSuccessDir(src, dest, done)
       })
-      it(`should move the directory successfully when dest is 'src-dest'`, done => {
+      it("should move the directory successfully when dest is 'src-dest'", done => {
         const dest = path.join(TEST_DIR, 'src-dest')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'dest_src'`, done => {
+      it("should move the directory successfully when dest is 'dest_src'", done => {
         const dest = path.join(TEST_DIR, 'dest_src')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'src_dest/src'`, done => {
+      it("should move the directory successfully when dest is 'src_dest/src'", done => {
         const dest = path.join(TEST_DIR, 'src_dest', 'src')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'src-dest/src'`, done => {
+      it("should move the directory successfully when dest is 'src-dest/src'", done => {
         const dest = path.join(TEST_DIR, 'src-dest', 'src')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'dest_src/src'`, done => {
+      it("should move the directory successfully when dest is 'dest_src/src'", done => {
         const dest = path.join(TEST_DIR, 'dest_src', 'src')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'src_src/dest'`, done => {
+      it("should move the directory successfully when dest is 'src_src/dest'", done => {
         const dest = path.join(TEST_DIR, 'src_src', 'dest')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'src-src/dest'`, done => {
+      it("should move the directory successfully when dest is 'src-src/dest'", done => {
         const dest = path.join(TEST_DIR, 'src-src', 'dest')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'srcsrc/dest'`, done => {
+      it("should move the directory successfully when dest is 'srcsrc/dest'", done => {
         const dest = path.join(TEST_DIR, 'srcsrc', 'dest')
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should move the directory successfully when dest is 'dest/src'`, done => {
+      it("should move the directory successfully when dest is 'dest/src'", done => {
         const dest = path.join(TEST_DIR, 'dest', 'src')
         return testSuccessDir(src, dest, done)
       })
@@ -147,47 +144,28 @@ describe('+ move() - prevent moving into itself', () => {
         return testSuccessDir(src, dest, done)
       })
 
-      it(`should error when dest is 'src/dest'`, done => {
+      it("should error when dest is 'src/dest'", done => {
         const dest = path.join(TEST_DIR, 'src', 'dest')
         return testError(src, dest, done)
       })
 
-      it(`should error when dest is 'src/src_dest'`, done => {
+      it("should error when dest is 'src/src_dest'", done => {
         const dest = path.join(TEST_DIR, 'src', 'src_dest')
         return testError(src, dest, done)
       })
 
-      it(`should error when dest is 'src/dest_src'`, done => {
+      it("should error when dest is 'src/dest_src'", done => {
         const dest = path.join(TEST_DIR, 'src', 'dest_src')
         return testError(src, dest, done)
       })
 
-      it(`should error when dest is 'src/dest/src'`, done => {
+      it("should error when dest is 'src/dest/src'", done => {
         const dest = path.join(TEST_DIR, 'src', 'dest', 'src')
         return testError(src, dest, done)
       })
     })
 
     describe('>> when dest is a symlink', () => {
-      it('should error when dest points exactly to src', done => {
-        const destLink = path.join(TEST_DIR, 'dest-symlink')
-        fs.symlinkSync(src, destLink, 'dir')
-
-        const srclenBefore = klawSync(src).length
-        assert(srclenBefore > 2)
-
-        fs.move(src, destLink, err => {
-          assert.strictEqual(err.message, 'Source and destination must not be the same.')
-
-          const srclenAfter = klawSync(src).length
-          assert.strictEqual(srclenAfter, srclenBefore, 'src length should not change')
-
-          const link = fs.readlinkSync(destLink)
-          assert.strictEqual(link, src)
-          done()
-        })
-      })
-
       it('should error when dest is a subdirectory of src (bind-mounted directory with subdirectory)', done => {
         const destLink = path.join(TEST_DIR, 'dest-symlink')
         fs.symlinkSync(src, destLink, 'dir')
@@ -280,7 +258,7 @@ describe('+ move() - prevent moving into itself', () => {
         })
       })
 
-      it(`should move the directory successfully when dest is 'src_src/dest'`, done => {
+      it("should move the directory successfully when dest is 'src_src/dest'", done => {
         const srcLink = path.join(TEST_DIR, 'src-symlink')
         fs.symlinkSync(src, srcLink, 'dir')
 
@@ -292,7 +270,7 @@ describe('+ move() - prevent moving into itself', () => {
         })
       })
 
-      it(`should move the directory successfully when dest is 'srcsrc/dest'`, done => {
+      it("should move the directory successfully when dest is 'srcsrc/dest'", done => {
         const srcLink = path.join(TEST_DIR, 'src-symlink')
         fs.symlinkSync(src, srcLink, 'dir')
 
@@ -306,7 +284,7 @@ describe('+ move() - prevent moving into itself', () => {
     })
 
     describe('>> when dest is a symlink', () => {
-      it('should error when resolved dest path is exactly the same as resolved src path', done => {
+      it('should error when resolved dest path is exactly the same as resolved src path and dereferene is true', done => {
         const srcLink = path.join(TEST_DIR, 'src-symlink')
         fs.symlinkSync(src, srcLink, 'dir')
         const destLink = path.join(TEST_DIR, 'dest-symlink')
@@ -317,7 +295,7 @@ describe('+ move() - prevent moving into itself', () => {
         assert(srclenBefore > 2)
         assert(destlenBefore > 2)
 
-        fs.move(srcLink, destLink, err => {
+        fs.move(srcLink, destLink, { dereference: true }, err => {
           assert.strictEqual(err.message, 'Source and destination must not be the same.')
 
           const srclenAfter = klawSync(srcLink).length
