@@ -8,6 +8,8 @@ const assert = require('assert')
 
 /* global afterEach, beforeEach, describe, it */
 
+const describeIfWindows = process.platform === 'win32' ? describe : describe.skip
+
 function createAsyncErrFn (errCode) {
   const fn = function (...args) {
     fn.callCount++
@@ -63,7 +65,7 @@ describe('+ move()', () => {
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           done()
         })
       })
@@ -114,7 +116,7 @@ describe('+ move()', () => {
         fs.readFile(path.join(dest, 'another-folder', 'file3'), 'utf8', (err, contents) => {
           const expected = /^knuckles\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           tearDownMockFs()
           done()
         })
@@ -132,7 +134,7 @@ describe('+ move()', () => {
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           done()
         })
       })
@@ -206,7 +208,7 @@ describe('+ move()', () => {
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           done()
         })
       })
@@ -225,7 +227,7 @@ describe('+ move()', () => {
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           tearDownMockFs()
           done()
         })
@@ -244,7 +246,7 @@ describe('+ move()', () => {
         fs.readFile(path.join(dest, 'another-file'), 'utf8', (err, contents) => {
           const expected = /^tails\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           done()
         })
       })
@@ -263,7 +265,7 @@ describe('+ move()', () => {
         fs.readFile(path.join(dest, 'another-folder', 'file3'), 'utf8', (err, contents) => {
           const expected = /^knuckles\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           tearDownMockFs()
           done()
         })
@@ -271,6 +273,27 @@ describe('+ move()', () => {
     })
   })
 
+  describeIfWindows('> when dest parent is root', () => {
+    let dest
+
+    afterEach(done => fse.remove(dest, done))
+
+    it('should not create parent directory', done => {
+      const src = path.join(TEST_DIR, 'a-file')
+      dest = path.join(path.parse(TEST_DIR).root, 'another-file')
+
+      fse.move(src, dest, err => {
+        assert.ifError(err)
+        fs.readFile(dest, 'utf8', (err, contents) => {
+          const expected = /^sonic the hedgehog\r?\n$/
+          assert.ifError(err)
+          assert.ok(contents.match(expected))
+          done()
+        })
+      })
+    })
+  })
+
   describe('> clobber', () => {
     it('should be an alias for overwrite', done => {
       const src = path.join(TEST_DIR, 'a-file')
@@ -284,7 +307,7 @@ describe('+ move()', () => {
         fs.readFile(dest, 'utf8', (err, contents) => {
           const expected = /^sonic the hedgehog\r?\n$/
           assert.ifError(err)
-          assert.ok(contents.match(expected), `${contents} match ${expected}`)
+          assert.ok(contents.match(expected))
           done()
         })
       })
